UploadMachineDTO class
Properties
children
→ List <String >
Set of state machine ids representing the regions of the state machine.
final
diagram
→ String
Diagram representing a state machine that visualization server will
render for connecting viewers in wbe browsers.
final
domain
→ String
domain is to distinguish between processes on the same client machine
by the visualization server. It is better than using pid that always
changes thus makes impossible to simply (and automatically)
final
hashCode
→ int
The hash code for this object.
no setter inherited
hostname
→ String
hostname to distinguish between machines in visualization server.
final
name
→ String
no setter override
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
smId
→ String
State machine identifier unique for a client process.
final
hisma_visual_monitor 0.4.0+3